@@ -4,8 +4,6 @@ from .settings_component import SettingsComponent
 from . import resources
 
 from .editorconfig import editorconfig
-from .codebuild import codebuild
-from .script import cistart
 from .precommit import precommitconfig
 from .docker_compose import docker_compose
 from .backend import backend
@@ -19,8 +17,6 @@ components = [
     backend,
     frontend,
     reverse_proxy,
-    codebuild,
-    cistart,
 ]
 
 __all__ = [
